import request from '@/utils/request'

/**
 *  获取等级机关6月5号新增
 * @returns {[{label: string, value: string},{label: string, value: string},{label: string, value: string},{label: string, value: string},{label: string, value: string},null,null,null,null,null,null,null]}
 */
export function getRegorgList() {
  const list = [{
    value: '440101',
    label: '广州市市场监督管理局'
  }, {
    value: '440102',
    label: '广州市荔湾区市场监督管理局'
  }, {
    value: '440104',
    label: '广州市越秀区市场监督管理局'
  }, {
    value: '440105',
    label: '广州市海珠区市场监督管理局'
  }, {
    value: '440106',
    label: '广州市天河区市场监督管理局'
  }, {
    value: '440110',
    label: '广州市南沙区市场监督管理局'
  }, {
    value: '440111',
    label: '广州市白云区市场监督管理局'
  }, {
    value: '440112',
    label: '广州市黄埔区市场监督管理局'
  }, {
    value: '440121',
    label: '广州市花都区市场监督管理局'
  }, {
    value: '440122',
    label: '广州市从化区市场监督管理局'
  }, {
    value: '440125',
    label: '广州市增城区市场监督管理局'
  }, {
    value: '440126',
    label: '广州市番禺区市场监督管理局'
  }]
  return list
}

/**
 * 获取惩戒来源清单 临时
 */
export function getPunishFromList() {
  const list = [{
    value: '1',
    label: '安全生产黑名单（安监总局）'
  }, {
    value: '2',
    label: '海关高级认证企业名单（海关总署）'
  }, {
    value: '4',
    label: '2017年第一批严重违法超限超载运输失信当事人名单（交通运输部）'
  }, {
    value: '5',
    label: '统计上严重失信企业汇总表（国家统计局）'
  }, {
    value: '6',
    label: '市场禁入（证监会）'
  }, {
    value: '7',
    label: '2016年度出入境检验检疫严重失信企业名单（质检总局）'
  }, {
    value: '8',
    label: '严重质量失信企业名单（质检总局）'
  }, {
    value: '9',
    label: '重大税收违法案件当事人名单（税务总局）'
  }, {
    value: '11',
    label: '电子商务失信问题专项治理黑名单汇总表（发改委）'
  }, {
    value: '12',
    label: '涉金融黑名单（发改委）'
  }, {
    value: '13',
    label: '2018年第一批拖欠农民工工资“黑名单”信息表'
  }, {
    value: '14',
    label: '企业环保信用评定'
  }]
  return list
}
/**
 * 获取惩戒来源清单 临时
 */
export function getDepartmentList() {
  const list = [{
    value: '1',
    label: '安监部门'
  }, {
    value: '2,3',
    label: '海关'
  }, {
    value: '4',
    label: '交通运输部门'
  }, {
    value: '5',
    label: '国家统计局'
  }, {
    value: '6',
    label: '证监会'
  }, {
    value: '7,8',
    label: '质检总局'
  }, {
    value: '9,10',
    label: '税务总局'
  }, {
    value: '11,12',
    label: '发改部门'
  }, {
    value: '13',
    label: '广州市人力资源和社会保障局'
  }, {
    value: '14',
    label: '广州市生态环境局'
  }]
  return list
}
/**
 * 获取惩戒来源清单 临时
 */
export function getulockspecificreason() {
  const list = [{
    value: '2',
    label: '企业已吊销，未注销'
  }, {
    value: '3',
    label: '企业已吊销，已注销'
  }, {
    value: '4',
    label: '企业已注销'
  }, {
    value: '5',
    label: '企业已撤销'
  }, {
    value: '6',
    label: '企业已迁出'
  }, {
    value: '0',
    label: '未在惩戒名单中'
  }]
  return list
}
/**
 * 联合惩戒锁定 主体列表
 */
export function toLockEntListPage(data) {
  return request({
    url: '/tolockentlist/toLockEntListPage',
    method: 'post',
    data
  })
}
/**
 * 联合惩戒解锁 主体列表
 */
export function toUnLockEntListPage(data) {
  return request({
    url: '/entlock/toUnLockEntListPage',
    method: 'post',
    data
  })
}
/**
 * 联合惩戒 业户锁定列表查询
 */
export function entlockListPage(data) {
  return request({
    url: '/entlock/entlockListPage',
    method: 'post',
    data
  })
}
/**
 * 保存联合惩戒锁定受理
 * @param {string} pripids 主体pripid
 * @param {string} punishFrom 惩戒来源
 * @author Lee
 * @since 2021年6月6日 02点20分
 */
export function saveLockAccept(pripids, punishFrom) {
  const form = new FormData()
  form.append('pripids', pripids)
  form.append('punishFrom', punishFrom)
  return request({
    url: '/tsbizPunishLock/saveAccept',
    method: 'post',
    data: form
  })
}
/**
 * 保存联合惩戒解锁受理
 * @param {string} elIds  业户锁定id
 * @author Lee
 * @since 2021年6月6日 02点20分
 */
export function saveUnlockAccept(elIds) {
  const form = new FormData()
  form.append('elIds', elIds)
  return request({
    url: '/tsbizpunishunlock/saveAccept',
    method: 'post',
    data: form
  })
}
/**
 * 锁定业务主体惩戒信息列表
 */
export function getEntInfoPageandPunishFrom(data) {
  return request({
    url: '/tsbizPunishLock/getEntInfoPageandPunishFrom',
    method: 'post',
    data
  })
}

/**
 * 解锁业务主体锁定信息列表
 */
export function getEntLockPageandPunishFrom(data) {
  return request({
    url: '/tsbizpunishunlock/getEntLockPageandPunishFrom',
    method: 'post',
    data
  })
}
/**
 * 锁定流程下一步
 * @param {object}} data 数据
 * @author Lee
 * @since 2021年6月6日 09点24分
 */
export function next(data) {
  const form = new FormData()
  for (const key in data) {
    form.append(key, data[key])
  }
  return request({
    url: '/tsbizPunishLock/next',
    method: 'post',
    data: form
  })
}
/**
 * 解锁流程下一步
 * @param {object}} data 数据
 * @author Lee
 * @since 2021年6月6日 09点24分
 */
export function unlockNext(data) {
  const form = new FormData()
  for (const key in data) {
    form.append(key, data[key])
  }
  return request({
    url: '/tsbizpunishunlock/next',
    method: 'post',
    data: form
  })
}
/**
 * 获取锁定类型清单 临时
 */
export function getLockTypeList() {
  const list = [{
    value: '001',
    label: '警告'
  }, {
    value: '002',
    label: '股权锁定'
  }, {
    value: '003',
    label: '完全锁定'
  }, {
    value: '004',
    label: '注销锁定'
  }, {
    value: '005',
    label: '变更事项锁定'
  }]
  return list
}
/**
 * 获取企业状态清单 临时
 */
export function getRegStateNameList() {
  const list = [{
    value: '1',
    label: '在营（开业）'
  }, {
    value: '003',
    label: '在营（开业）'
  }, {
    value: '003001',
    label: '在营（开业）'
  }, {
    value: '2',
    label: '吊销，未注销'
  }, {
    value: '3',
    label: '吊销，已注销'
  }, {
    value: '4',
    label: '注销'
  }, {
    value: '5',
    label: '撤销'
  }, {
    value: '6',
    label: '迁出'
  }]
  return list
}

export function getStateList() {
  const list = [{
    value: '0',
    label: '锁定'
  }, {
    value: '3',
    label: '解锁'
  }]
  return list
}

export function getStatusList() {
  const list = [{
    value: '0',
    label: '未解锁'
  }, {
    value: '2',
    label: '解锁中'
  }, {
    value: '3',
    label: '已解锁'
  }]
  return list
}
/**
 * 获取当前查询条件下的所有拟锁定主体
 * @author Lee
 * @since 2021年6月28日 15点29分
 */
export function selectAllWithNopage(data) {
  const form = new FormData()
  for (const key in data) {
    form.append(key, data[key])
  }
  return request({
    url: '/tolockentlist/selectAllWithNopage',
    method: 'post',
    data: form
  })
}
/**
 * 获取惩戒措施列表清单
 * @author Lee
 * @since 2021年6月28日 15点29分
 */
export function getMeasureList(punishfrom) {
  return request({
    url: '/punishmeasures/getMeasureList?punishfrom=' + punishfrom,
    method: 'get'
  })
}
/**
 * 获取惩戒措施列表分页
 */
export function measureListPage(data) {
  return request({
    url: '/punishmeasures/measureListPage',
    method: 'post',
    data
  })
}
/**
 * 根据措施id删除
 */
export function deleteMeasure(measureIds) {
  const form = new FormData()
  form.append('measureIds', measureIds)
  return request({
    url: '/punishmeasures/deleteMeasure',
    method: 'post',
    data: form
  })
}
/**
 * 根据措施id删除
 */
export function savePunishMeasure(data) {
  const form = new FormData()
  for (const key in data) {
    form.append(key, data[key])
  }
  return request({
    url: '/punishmeasures/saveMeasure',
    method: 'post',
    data: form
  })
}
/**
 * 锁定异常数据导出
 */
export function exportExcel(data) {
  return request({
    url: '/tolockentlist/exportExcel',
    method: 'post',
    responseType: 'blob',
    data
  })
}

/**
 * 锁定上传
 * @param data
 */
export function saveAccept(data) {
  return request({
    url: '/tolockentlist/saveAccept',
    method: 'post',
    data
  })
}

/**
 * 锁定单条新增查找
 * @param punishFrom
 * @param uniscid
 * @param entname
 * @param regno
 */
export function queryOne(uniscid) {
  const form = new FormData()
  form.append('uniscid', uniscid)
  return request({
    url: '/tolockentlist/queryOne',
    method: 'post',
    data: form
  })
}

/**
 * 锁定单条新增
 * @param punishFrom
 * @param uniscid
 * @param entname
 * @param regno
 */
export function saveOneAndAccept(punishFrom, uniscid, entname, regno) {
  const form = new FormData()
  form.append('punishFrom', punishFrom)
  form.append('uniscid', uniscid)
  form.append('entname', entname)
  form.append('regno', regno)
  return request({
    url: '/tolockentlist/saveOneAndAccept',
    method: 'post',
    data: form
  })
}

/**
 * 解锁数据上传
 * @param data
 */
export function saveAcceptByUpload(data) {
  return request({
    url: '/tsbizpunishunlock/saveAcceptByUpload',
    method: 'post',
    data
  })
}
/**
 * 解锁异常数据导出
 */
export function unLockExportExcel(data) {
  return request({
    url: '/tsbizpunishunlock/exportExcel',
    method: 'post',
    responseType: 'blob',
    data
  })
}

/**
 * 惩戒措施查询
 */
export function queryAllPunishMeasures() {
  return request({
    url: '/punishmeasures/queryAll',
    method: 'get'
  })
}

/**
 * 查询页数据导出
 */
export function entLockExcel(data) {
  return request({
    url: '/entlock/exportExcel',
    method: 'post',
    responseType: 'blob',
    data
  })
}

export function downLoadFile(id) {
  return request({
    url: '/attachment/download?id=' + id,
    method: 'get',
    responseType: 'blob'
  })
}

export function groupDepart(data) {
  return request({
    url: '/tolockentlist/groupDepart',
    method: 'post',
    data
  })
}
export function listTolockentlist(data) {
  return request({
    url: '/tolockentlist/list',
    method: 'post',
    data
  })
}
export function listEntlock(data) {
  return request({
    url: '/entlock/list',
    method: 'post',
    data
  })
}
export function checkpunishlock(data) {
  return request({
    url: '/tsbizPunishLock/checkpunishlock',
    method: 'post',
    data
  })
}

export function select(params) {
  return request({
    url: '/entlock/selectByEntname',
    method: 'get',
    params
  })
}

export function queryOrgDept(id) {
  return request({
    url: '/entlock/queryOrgDept?id=' + id,
    method: 'get'
  })
}

export function toDetail(data) {
  return request({
    url: '/entlock/toDetail',
    method: 'post',
    data
  })
}
